@@ -101,10 +101,7 @@ def send_help():
     print('USAGE: build [options]')
     print('A build tool created by Ehnryu\n')
     print('Basic options:\n')
-    print('--help : this command\n')
-    print('--build : build a project\n')
-    print('--sendargs : send arguments to a project\n')
-    print('--runfunc : run a specialized function\n')
+    print('--compress : compress an archive\n')
 
 def printc(color,*text):
   CEND      = '\33[0m'
@@ -116,7 +113,7 @@ def run(command):
     subprocess.check_output(command,shell=True)
 
 def main():
-    advanced = ["help","sendargs =","runfunc =","build"]
+    advanced = ["sendargs =","runfunc =","build"]
 
 
     argv = sys.argv[1:]
@@ -149,7 +146,7 @@ def main():
 
 
 
-
+x = main()
 
 def default(x):
   if x != None:
@@ -201,6 +198,12 @@ def default(x):
               item = item.replace("*getargs",str(argz).rstrip())
               item = item.replace("*getplatform",str(sys.platform).rstrip())
               item = item.replace("*getvars",str(vars))
+              from datetime import datetime
+
+              now = datetime.now()
+
+              current_time = now.strftime("%H:%M:%S")
+              item = item.replace("*getime",current_time)
 
 
               lzma = False
@@ -459,7 +462,7 @@ def default(x):
       elif "Makefile" in files:
         printc(CVIOLET,"Running make ...")
         run("make")
+default(x)
 
 if __name__ == "__main__":
-    x = main()
-    default(x)
+    main()
\ No newline at end of file
